package eu.clarin.cmdi.virtualcollectionregistry;

import eu.clarin.cmdi.virtualcollectionregistry.model.User;
import eu.clarin.cmdi.virtualcollectionregistry.model.VirtualCollection;
import eu.clarin.cmdi.virtualcollectionregistry.model.VirtualCollectionList;
import java.security.Principal;
import java.util.List;

public interface VirtualCollectionRegistry {

    /**
     * Will store the specified collection; it will also set the owner according
     * to the specified principal and set its state to
     * {@link VirtualCollection.State#PRIVATE}
     *
     * @param principal owner principal
     * @param vc collection to store
     * @return identifier of the persisted collection
     * @throws VirtualCollectionRegistryException
     */
    long createVirtualCollection(Principal principal,
            VirtualCollection vc) throws VirtualCollectionRegistryException;

    long updateVirtualCollection(Principal principal, long id,
            VirtualCollection vc) throws VirtualCollectionRegistryException;

    long deleteVirtualCollection(Principal principal, long id)
            throws VirtualCollectionRegistryException;

    VirtualCollection.State getVirtualCollectionState(long id)
            throws VirtualCollectionRegistryException;

    void setVirtualCollectionState(Principal principal, long id,
            VirtualCollection.State state)
            throws VirtualCollectionRegistryException;

    /**
     *
     * @param id identifier of the virtual collection to retrieve
     * @return the identified virtual collection, never null
     * @throws VirtualCollectionRegistryException if no virtual collection with
     * the specified identifier exists
     */
    VirtualCollection retrieveVirtualCollection(long id)
            throws VirtualCollectionRegistryException;

    VirtualCollectionList getVirtualCollections(String query,
            int offset, int count) throws VirtualCollectionRegistryException;

    VirtualCollectionList getVirtualCollections(Principal principal,
            String query, int offset, int count)
            throws VirtualCollectionRegistryException;

    int getVirtualCollectionCount(QueryOptions options)
            throws VirtualCollectionRegistryException;

    List<User> getUsers();

    List<VirtualCollection> getVirtualCollections(
            int first, int count, QueryOptions options)
            throws VirtualCollectionRegistryException;

} // interface VirtualCollectionRegistry
